@@ -15,8 +15,8 @@ enum State {
     Flapping,
 }
 
-struct Character {
-    object: ObjectStandard,
+struct Character<'a> {
+    object: ObjectStandard<'a>,
     position: Vector2D,
     velocity: Vector2D,
 }
@@ -31,8 +31,8 @@ fn tile_is_collidable(tile: u16) -> bool {
     masked == 0 || masked == 4
 }
 
-fn frame_ranger(count: u32, start: u32, end: u32, delay: u32) -> u32 {
-    ((count / delay) % (end + 1 - start)) + start
+fn frame_ranger(count: u32, start: u32, end: u32, delay: u32) -> u16 {
+    (((count / delay) % (end + 1 - start)) + start) as u16
 }
 
 #[no_mangle]
@@ -48,22 +48,21 @@ pub fn main() -> ! {
     let vblank = gba.display.vblank.get();
     let mut input = agb::input::ButtonController::new();
 
-    gfx.set_sprite_palette(&CHICKEN_PALETTE);
+    gfx.set_sprite_palette_raw(&CHICKEN_PALETTE);
     gfx.set_sprite_tilemap(&CHICKEN_TILES);
 
     gfx.set_background_palette_raw(&MAP_PALETTE);
     gfx.set_background_tilemap(0, &MAP_TILES);
 
     let mut background = gfx.get_background().unwrap();
-    background.set_map(&MAP_MAP, 32, 32);
+    background.draw_full_map(&MAP_MAP, (32_u32, 32_u32).into(), 0);
     background.show();
 
-    let mut object = gfx.object;
+    let mut object = gba.display.object.get();
 
     object.enable();
-    unsafe { object.clear_objects() };
     let mut chicken = Character {
-        object: unsafe { object.get_object(0) },
+        object: object.get_object_standard(),
         position: Vector2D {
             x: (6 * 8) << 8,
             y: ((7 * 8) - 4) << 8,
@@ -152,8 +151,8 @@ fn update_chicken_object(chicken: &mut Character, state: State, frame_count: u32
         }
     }
 
-    let x: u8 = (chicken.position.x >> 8).try_into().unwrap();
-    let y: u8 = (chicken.position.y >> 8).try_into().unwrap();
+    let x: u16 = (chicken.position.x >> 8).try_into().unwrap();
+    let y: u16 = (chicken.position.y >> 8).try_into().unwrap();
 
     chicken.object.set_x(x - 4);
     chicken.object.set_y(y - 4);
